#
# spec file for package kor
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           kor
Version:        0.3.3
Release:        1.1
Summary:        Tool to discover unused Kubernetes Resources
License:        MIT
URL:            https://github.com/yonahd/kor
Source:         kor-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.17

%description
Kor is a tool to discover unused Kubernetes resources. Currently, Kor can identify and list unused:
- ConfigMaps
- Secrets
- Services
- ServiceAccounts
- Deployments
- StatefulSets
- Roles
- HPAs
- PVCs
- Ingresses
- PDBs

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X github.com/GoogleContainerTools/kor/pkg/kor/version.version=%{version} -X github.com/GoogleContainerTools/kor/pkg/kor/version.buildDate=$BUILD_DATE" \
   -o bin/kor

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%changelog
* Mon Jan 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.3.3:
  * Add finalizer subcommand (#172)
  * chore(deps): bump github.com/prometheus/client_golang (#185)
  * feat: add replicaset cleaner (#180)
  * chore(deps): bump k8s.io/apiextensions-apiserver from 0.28.4 to
    0.29.0 (#182)
  * chore(deps): bump k8s.io/client-go from 0.28.4 to 0.29.0 (#183)
  * Fix spaces and lots labels. (#177)
* Sun Dec 10 2023 kastl@b1-systems.de
- Update to version 0.3.2:
  * Add labels to all templates. (#174)
  * Fix command in templates. (#175)
  * Fix exporterInterval variable. (#176)
  * feat: find evicted pods (#173)
  * feat: add jobs cleaner (#168)
  * Add discord server to Readme (#171)
* Thu Nov 30 2023 kastl@b1-systems.de
- Update to version 0.3.1:
  * fix ingress flag as used (#169)
  * Feat: Find unused pv (#163)
  * feat:add version flag to ldflags and print version in banner
    (#158)
  * Bump k8s.io/apiextensions-apiserver from 0.28.3 to 0.28.4
    (#162)
* Thu Nov 16 2023 kastl@b1-systems.de
- Update to version 0.3.0:
  * feat: add inUse label prompt for non deleted resources (#150)
  * add ability to discover projected secrets (#156)
* Tue Nov 14 2023 kastl@b1-systems.de
- Update to version 0.2.9:
  * doc: add verbose flag (#154)
  * fix: fix output banner for yaml and json (#153)
  * fix incorrect example namespace flags (#152)
  * fix: fix output for yaml and json, banner (#149)
  * chore: add missing filters to service and SA (#148)
  * fix: make verbose logs a flag (#147)
  * chore: cleanup unused and remove dup (#146)
* Mon Nov 13 2023 kastl@b1-systems.de
- Update to version 0.2.8:
  * Crd Readme and multi support (#144)
  * Bump github.com/fatih/color from 1.15.0 to 1.16.0 (#143)
  * Refactor the GetUnusedMulti function (#142)
  * chore: update to golang 1.21 and scratch (#141)
  * feat: add support for linux arm64 (#139)
  * add support for finding unused CRDs (#134)
  * grafana dashboard ds selector and repeat kinds (#135)
  * Fix exporter typo (#133)
  * fix: clear counter between iterations (#132)
  * fix: add filter options in export command (#129)
* Mon Nov  6 2023 kastl@b1-systems.de
- Update to version 0.2.7:
  * Document: add delete flag in Readme (#127)
  * Bump github.com/spf13/cobra from 1.7.0 to 1.8.0 (#126)
  * fix: Resolve panic error due to redefined flag in kor (#125)
  * feat: add delete flag (#120)
* Wed Nov  1 2023 kastl@b1-systems.de
- Update to version 0.2.6:
  * feat: add customization and filtering options for finding
    unused resources (#116)
  * Add Grafana Dashboard (#118)
  * Bump sigs.k8s.io/yaml from 1.3.0 to 1.4.0 (#119)
  * Bump k8s.io/client-go from 0.28.2 to 0.28.3 (#112)
  * Documentation: update chart with release v0.2.5 (#111)
* Fri Oct 20 2023 kastl@b1-systems.de
- Update to version 0.2.5:
  * Fix: validate HTTP field (#110)
  * merge functions for configmaps (#108)
  * Add helm documentation (#104)
  * Fix: Add helm condition to skip secret manifest creation when
    slack secrets are not provided (#101)
  * Bump github.com/prometheus/client_golang from 1.16.0 to 1.17.0
    (#99)
* Fri Oct 13 2023 kastl@b1-systems.de
- Update to version 0.2.4:
  * Fix: add Logo (#98)
  * Add Logo (#96)
  * Update helm charts with deployment support (#90)
  * Export Prometheus metrics (#87)
  * Add feature request template
  * add helm to the installation options (#93)
  * feat: add send to slack support (#77)
  * Update installation instructions to README.md (#88)
  * feat: add helm charts with cronjob support (#78)
  * style: consistent language (#85)
* Fri Oct 13 2023 Johannes Kastl <kastl@b1-systems.de>
- new package kor: Tool to discover unused Kubernetes Resources
